/////////////////////////////////////////////////////////////////////////////
// Name:        mchoidgg.cpp
// Purpose:     Multiple choice dialogs 
// Author:      Robert Cowell (based upon choicdgg.cpp)
// Modified by: 
// Created:     14/03/2001
// RCS-ID:      
// Copyright:   (c) Julian Smart and Markus Holzem and Robert Cowell
// Licence:     wxWindows license
/////////////////////////////////////////////////////////////////////////////

#ifdef __GNUG__
    #pragma implementation "choicdgg.h"
#endif

// For compilers that support precompilation, includes "wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

#ifndef WX_PRECOMP
    #include <stdio.h>
    #include "wx/utils.h"
    #include "wx/dialog.h"
    #include "wx/button.h"
    #include "wx/listbox.h"
    #include "wx/stattext.h"
    #include "wx/intl.h"
    #include "wx/sizer.h"
#endif

#if wxUSE_STATLINE
    #include "wx/statline.h"
#endif

#include "mchodgg.h"

#define wxID_LISTBOX 3579


wxArrayString wxGetMultipleChoice( const wxString& message, const wxString& caption, int n,
                            const wxString *choices, const wxArrayInt &priorChoices,
							wxWindow *parent,
                            int WXUNUSED(x), int WXUNUSED(y), bool WXUNUSED(centre),
                            int WXUNUSED(width), int WXUNUSED(height) )
{
    wxMultipleChoiceDialog dialog(parent, message, caption, n, choices, priorChoices);
    wxArrayString choice;
    if ( dialog.ShowModal() == wxID_OK )
        dialog.GetStringSelections(choice);

    return choice;
}

// Overloaded for backward compatibility
wxArrayString wxGetMultipleChoice( const wxString& message, const wxString& caption, int n,
                            char *choices[], const wxArrayInt &priorChoices,
							wxWindow *parent,
                            int x, int y, bool centre,
                            int width, int height )
{
    wxString *strings = new wxString[n];
    int i;
    for ( i = 0; i < n; i++)
    {
        strings[i] = choices[i];
    }
    wxArrayString ans = wxGetMultipleChoice(message, caption, n, 
		(const wxString *)strings, priorChoices, parent,
        x, y, centre, width, height);
    delete[] strings;
    return ans;
}

wxArrayInt wxGetMultipleChoiceIndex( const wxString& message, const wxString& caption, int n,
                            const wxString *choices, const wxArrayInt &priorChoices,
							wxWindow *parent,
                int WXUNUSED(x), int WXUNUSED(y), bool WXUNUSED(centre),
                int WXUNUSED(width), int WXUNUSED(height) )
{
    wxMultipleChoiceDialog dialog(parent, message, caption, n, choices, priorChoices);
    wxArrayInt choice;
    if ( dialog.ShowModal() == wxID_OK )
         dialog.GetSelections(choice);
     return choice;
}

// Overloaded for backward compatibility
wxArrayInt wxGetMultipleChoiceIndex( const wxString& message, const wxString& caption, int n,
                            wxChar *choices[], const wxArrayInt &priorChoices,
							wxWindow *parent,
                int x, int y, bool centre,
                int width, int height )
{
    wxString *strings = new wxString[n];
    for ( int i = 0; i < n; i++)
        strings[i] = choices[i];
    wxArrayInt ans = wxGetMultipleChoiceIndex(message, caption, n, 
		(const wxString *)strings, priorChoices, parent,
        x, y, centre, width, height);
    delete[] strings;
    return ans;
}

wxArrayPtrVoid wxGetMultipleChoiceData( const wxString& message, const wxString& caption, int n,
                   const wxString *choices, const wxArrayInt &priorChoices,
				   void **client_data, wxWindow *parent,
                   int WXUNUSED(x), int WXUNUSED(y), bool WXUNUSED(centre),
                   int WXUNUSED(width), int WXUNUSED(height) )
{
    wxMultipleChoiceDialog dialog(parent, message, caption, n, choices, 
		priorChoices, (char **)client_data);
    wxArrayPtrVoid data;
    if ( dialog.ShowModal() == wxID_OK )
         dialog.GetSelectionsClientData(data);
    return data;
}

// Overloaded for backward compatibility
wxArrayPtrVoid wxGetMultipleChoiceData( const wxString& message, const wxString& caption, int n,
                   wxChar *choices[], const wxArrayInt &priorChoices,
				   void **client_data, wxWindow *parent,
                   int x, int y, bool centre,
                   int width, int height )
{
    wxString *strings = new wxString[n];
    int i;
    for ( i = 0; i < n; i++)
    {
        strings[i] = choices[i];
    }
    wxArrayPtrVoid data = wxGetMultipleChoiceData(message, caption, n, 
		(const wxString *)strings, priorChoices, client_data, parent,
        x, y, centre, width, height);
    delete[] strings;
    return data;
}


// wxMultipleChoiceDialog

BEGIN_EVENT_TABLE(wxMultipleChoiceDialog, wxDialog)
    EVT_BUTTON(wxID_OK, wxMultipleChoiceDialog::OnOK)
    EVT_LISTBOX_DCLICK(wxID_LISTBOX, wxMultipleChoiceDialog::OnListBoxDClick)
END_EVENT_TABLE()

IMPLEMENT_CLASS(wxMultipleChoiceDialog, wxDialog)

#if defined(__WXMSW__) || defined(__WXMAC__)
#define wxCHOICEDLG_DIALOG_STYLE (wxDEFAULT_DIALOG_STYLE | \
                                  wxDIALOG_MODAL |         \
                                  wxTAB_TRAVERSAL)
#else
#define wxCHOICEDLG_DIALOG_STYLE (wxDEFAULT_DIALOG_STYLE | \
                                  wxDIALOG_MODAL |         \
                                  wxRESIZE_BORDER |        \
                                  wxTAB_TRAVERSAL)
#endif


wxMultipleChoiceDialog::wxMultipleChoiceDialog(wxWindow *parent,
                                           const wxString& message,
                                           const wxString& caption,
                                           int n,
                                           const wxString *choices,
                                           const wxArrayInt &priorChoices,
										   char **clientData,
                                           long style,
                                           const wxPoint& pos)
                    : wxDialog(parent, -1, caption, pos, wxDefaultSize,
                               wxCHOICEDLG_DIALOG_STYLE)
{
    Create(parent, message, caption, n, choices, priorChoices, clientData, style);
}

wxMultipleChoiceDialog::wxMultipleChoiceDialog(wxWindow *parent,
                                           const wxString& message,
                                           const wxString& caption,
                                           const wxStringList& choices,
                                           const wxArrayInt &priorChoices,
										   char **clientData,
                                           long style,
                                           const wxPoint& pos)
                    : wxDialog(parent, -1, caption, pos, wxDefaultSize,
                               wxCHOICEDLG_DIALOG_STYLE)
{
    Create(parent, message, caption, choices, priorChoices, clientData, style);
}

bool wxMultipleChoiceDialog::Create(wxWindow *parent,
                                  const wxString& message,
                                  const wxString& caption,
                                  const wxStringList& choices,
                                  const wxArrayInt &priorChoices,
								  char **clientData,
                                  long style,
                                  const wxPoint& pos)
{
    wxString *strings = new wxString[choices.Number()];
    int i;
    for ( i = 0; i < choices.Number(); i++)
    {
        strings[i] = (char *)choices.Nth(i)->Data();
    }
    bool ans = Create(parent, message, caption, choices.Number(), 
			strings, priorChoices, clientData, style, pos);
    delete[] strings;
    return ans;
}

bool wxMultipleChoiceDialog::Create( wxWindow *WXUNUSED(parent),
                                   const wxString& message,
                                   const wxString& WXUNUSED(caption),
                                   int n,
                                   const wxString *choices,
                                   const wxArrayInt &priorChoices,
								   char **clientData,
                                   long style,
                                   const wxPoint& WXUNUSED(pos) )
{
    m_dialogStyle = style;

    wxBeginBusyCursor();

    wxBoxSizer *topsizer = new wxBoxSizer( wxVERTICAL );

    // 1) text message
    topsizer->Add( CreateTextSizer( message ), 0, wxALL, 10 );

    // 2) list box
    m_listbox = new wxListBox( this, wxID_LISTBOX, wxDefaultPosition, wxSize(160,100) ,
                                        n, choices, wxLB_ALWAYS_SB|wxLB_MULTIPLE );
    
    //for (unsigned int j=0; j < priorChoices.GetCount(); j++)
	//	if (priorChoices[j] >=0 && priorChoices[j] < n)
	//		m_listbox->SetSelection(priorChoices[j],TRUE);


	if (clientData)
    {
        for (int i = 0; i < n; i++)
            m_listbox->SetClientData(i, clientData[i]);
    }
	


    topsizer->Add( m_listbox, 1, wxEXPAND | wxLEFT|wxRIGHT, 15 );

#if wxUSE_STATLINE
    // 3) static line
    topsizer->Add( new wxStaticLine( this, -1 ), 0, wxEXPAND | wxLEFT|wxRIGHT|wxTOP, 10 );
#endif

    // 4) buttons
    topsizer->Add( CreateButtonSizer( wxOK|wxCANCEL ), 0, wxCENTRE | wxALL, 10 );

    SetAutoLayout( TRUE );
    SetSizer( topsizer );

    topsizer->SetSizeHints( this );
    topsizer->Fit( this );

    Centre( wxBOTH );

    m_listbox->SetFocus();

	SetSelections(priorChoices);
    wxEndBusyCursor();

    return TRUE;
}

// Set the selection


void wxMultipleChoiceDialog::OnOK(wxCommandEvent& WXUNUSED(event))
{
    m_listbox->GetSelections(m_selection);
	GetStringSelections(m_stringSelection);
    // TODO!
	// the next lines are unaltered from the corresponding lines for the single
	// choice dialog, excep they have been commented out. It is not sufficient to
	// uncomment them, but I don't know what they are doing so I cannot correct
	// them myself. Perhaps they are not needed? (RGC, 20/3/2001).
	//#ifndef __WXMOTIF__
	//    if ( m_listbox->HasClientUntypedData() )
	//        SetClientData(m_listbox->GetClientData(m_selection));
	//#endif
    EndModal(wxID_OK);
}

void wxMultipleChoiceDialog::OnListBoxDClick(wxCommandEvent& WXUNUSED(event))
{
    m_listbox->GetSelections(m_selection);
    GetStringSelections(m_stringSelection);
	
    // TODO!
	// the next lines are unaltered from the corresponding lines for the single
	// choice dialog, excep they have been commented out. It is not sufficient to
	// uncomment them, but I don't know what they are doing so I cannot correct
	// them myself. Perhaps they are not needed? (RGC, 20/3/2001).
	//#ifndef __WXMOTIF__
	//    if ( m_listbox->HasClientUntypedData() )
	//        SetClientData(m_listbox->GetClientData(m_selection));
	//#endif
	
    EndModal(wxID_OK);
}


void wxMultipleChoiceDialog::SetSelections(const wxArrayInt & ai)
{
	int n = ai.GetCount();
	int nl = m_listbox->Number();
	for (int i=0; i<nl; i++)
		m_listbox->SetSelection(i,FALSE);
	for (int j=0; j < n; j++)
		if (ai[j] >=0 && ai[j] < nl)
			m_listbox->SetSelection(ai[j],TRUE);
}


int wxMultipleChoiceDialog::GetSelections(wxArrayInt & ai)
{
	m_listbox->GetSelections(ai);
	return ai.GetCount();
}


int wxMultipleChoiceDialog::GetStringSelections(wxArrayString & as)
{
	wxArrayInt  ai;
   int count = GetSelections(ai);
	as.Clear();
	for (int i=0; i<count; i++)
		as.Add(m_listbox->GetString(ai[i]));
	return count;
}

int wxMultipleChoiceDialog::GetSelectionsClientData(wxArrayPtrVoid & ad)
{
	wxArrayInt  ai;
	int count = GetSelections(ai);
	ad.Clear();
	for (int i=0; i<count; i++)
		ad.Add(m_listbox->GetClientData(ai[i]));
	return count;
}