/////////////////////////////////////////////////////////////////////////////
// Name:        mchoidgg.h
// Purpose:     Multiple choice dialogs
// Author:      Robert Cowell (based upon choicdgg.h)
// Modified by: 
// Created:     17/03/2001
// RCS-ID:      
// Copyright:   (c) Julian Smart and Markus Holzem and Robert Cowell
// Licence:     wxWindows license
/////////////////////////////////////////////////////////////////////////////

#ifndef __MCHOICEDLGH_G__
#define __MCHOICEDLGH_G__

#ifdef __GNUG__
    #pragma interface "mchodgg.h"
#endif

#include "wx/dialog.h"

class WXDLLEXPORT wxListBox;

#define wxCHOICE_HEIGHT 150
#define wxCHOICE_WIDTH 200

#define wxCHOICEDLG_STYLE (wxDEFAULT_DIALOG_STYLE|wxOK | wxCANCEL | wxCENTRE)

class WXDLLEXPORT wxMultipleChoiceDialog: public wxDialog
{
    DECLARE_DYNAMIC_CLASS(wxMultipleChoiceDialog)

public:
    wxMultipleChoiceDialog(wxWindow *parent,
                         const wxString& message,
                         const wxString& caption,
                         int n,
                         const wxString *choices,
						 const wxArrayInt &priorChoices,
                         char **clientData = (char **)NULL,
					     long style = wxCHOICEDLG_STYLE,
                         const wxPoint& pos = wxDefaultPosition);

    wxMultipleChoiceDialog(wxWindow *parent,
                         const wxString& message,
                         const wxString& caption,
                         const wxStringList& choices,
                         const wxArrayInt &priorChoices,
                         char **clientData = (char **)NULL,
                         long style = wxCHOICEDLG_STYLE,
                         const wxPoint& pos = wxDefaultPosition);

    bool Create(wxWindow *parent,
                const wxString& message,
                const wxString& caption,
                int n,
                const wxString *choices,
                const wxArrayInt &priorChoices,
                char **clientData = (char **)NULL,
                long style = wxCHOICEDLG_STYLE,
                const wxPoint& pos = wxDefaultPosition);

    bool Create(wxWindow *parent,
                const wxString& message,
                const wxString& caption,
                const wxStringList& choices,
                const wxArrayInt &priorChoices,
                char **clientData = (char **)NULL,
                long style = wxCHOICEDLG_STYLE,
                const wxPoint& pos = wxDefaultPosition);

    void SetSelections(const wxArrayInt &);
    int  GetSelections(wxArrayInt &); 
    int  GetStringSelections(wxArrayString&); 
	int  GetSelectionsClientData(wxArrayPtrVoid &); 
    // implementation from now on
    void OnOK(wxCommandEvent& event);
    void OnListBoxDClick(wxCommandEvent& event);

protected:
    wxArrayInt  m_selection;
    long        m_dialogStyle;
    wxArrayString    m_stringSelection;
    wxListBox  *m_listbox;

private:
    DECLARE_EVENT_TABLE()
};

WXDLLEXPORT wxArrayString wxGetMultipleChoice(const wxString& message, const wxString& caption,
                        int n, const wxString *choices, const wxArrayInt &priorChoices,
						wxWindow *parent = (wxWindow *) NULL,
                        int x = -1, int y = -1, bool centre = TRUE,
                        int width = wxCHOICE_WIDTH, int height = wxCHOICE_HEIGHT);

WXDLLEXPORT wxArrayString wxGetMultipleChoice(const wxString& message, const wxString& caption,
                        int n, wxChar *choices[], const wxArrayInt &priorChoices,
						wxWindow *parent = (wxWindow *) NULL,
                        int x = -1, int y = -1, bool centre = TRUE,
                        int width = wxCHOICE_WIDTH, int height = wxCHOICE_HEIGHT);

// Same as above but gets positions in an array of ints, instead of an array of strings,
WXDLLEXPORT wxArrayInt wxGetMultipleChoiceIndex(const wxString& message, const wxString& caption,
                           int n, const wxString *choices, const wxArrayInt &priorChoices,
						   wxWindow *parent = (wxWindow *) NULL,
                           int x = -1, int y = -1, bool centre = TRUE,
                           int width = wxCHOICE_WIDTH, int height = wxCHOICE_HEIGHT);

WXDLLEXPORT wxArrayInt wxGetMultipleChoiceIndex(const wxString& message, const wxString& caption,
                           int n, wxChar *choices[], const wxArrayInt &priorChoices,
						   wxWindow *parent = (wxWindow *) NULL,
                           int x = -1, int y = -1, bool centre = TRUE,
                           int width = wxCHOICE_WIDTH, int height = wxCHOICE_HEIGHT);

WXDLLEXPORT wxArrayPtrVoid wxGetMultipleChoiceData(const wxString& message, const wxString& caption,
                            int n, const wxString *choices, const wxArrayInt &priorChoices,
							void **client_data,
                            wxWindow *parent = (wxWindow *) NULL, int x = -1, int y = -1,
                            bool centre = TRUE,
                            int width = wxCHOICE_WIDTH, int height = wxCHOICE_HEIGHT);

WXDLLEXPORT wxArrayPtrVoid wxGetMultipleChoiceData(const wxString& message, const wxString& caption,
                            int n, wxChar *choices[], const wxArrayInt &priorChoices,
							void **client_data,
                            wxWindow *parent = (wxWindow *) NULL, int x = -1, int y = -1,
                            bool centre = TRUE,
                            int width = wxCHOICE_WIDTH, int height = wxCHOICE_HEIGHT);

#endif
